@@ -19,6 +19,7 @@ Common stuff for cli tools.
 
 """
 import argparse
+import os
 import sys
 
 import nested_diff
@@ -29,9 +30,17 @@ class App(object):
     Base class for command line tools
 
     """
+    default_ifmt = 'auto'
+    default_ofmt = 'json'
+
+    supported_ifmts = ('auto', 'json', 'yaml')
+    supported_ofmts = ('json', 'yaml')
+
     version = nested_diff.__version__
 
     def __init__(self, args=None):
+        self.override_excepthook()  # ASAP, but overridable by descendants
+
         self.argparser = self.get_argparser(description=self.__doc__)
         self.args = self.argparser.parse_args(args=args)
 
@@ -39,10 +48,6 @@ class App(object):
             self.args.ofmt,
             **self._decode_fmt_opts(self.args.ofmt_opts)
         )
-        self.loader = self.get_loader(
-            self.args.ifmt,
-            **self._decode_fmt_opts(self.args.ifmt_opts)
-        )
 
     @staticmethod
     def _decode_fmt_opts(opts):
@@ -67,9 +72,10 @@ class App(object):
         parser.add_argument(
             '--ifmt',
             type=str,
-            default='json',
-            choices=('json', 'yaml'),
-            help='input files format; "json" used by default',
+            default=self.default_ifmt,
+            choices=sorted(self.supported_ifmts),
+            help='input files format; "' + self.default_ifmt +
+                 '" used by default',
         )
 
         parser.add_argument(
@@ -82,9 +88,10 @@ class App(object):
         parser.add_argument(
             '--ofmt',
             type=str,
-            default='json',
-            choices=('json', 'yaml'),
-            help='output files format; "json" used by default',
+            default=self.default_ofmt,
+            choices=sorted(self.supported_ofmts),
+            help='output files format; "' + self.default_ofmt +
+                 '" used by default',
         )
 
         parser.add_argument(
@@ -94,8 +101,22 @@ class App(object):
             help='output files format options',
         )
 
+        for name, opts in self.get_argparser_positional_args():
+            parser.add_argument(name, **opts)
+
         return parser
 
+    @staticmethod
+    def get_argparser_positional_args():
+        """
+        Yield tuples (name, opts) for each positional argument.
+
+        It's almost impossible to remove positional args from argparser, so
+        we use method here to be able to override it in subclasses.
+
+        """
+        return ()
+
     @staticmethod
     def get_dumper(fmt, **kwargs):
         if fmt == 'json':
@@ -105,6 +126,22 @@ class App(object):
 
         raise RuntimeError('Unsupported output format: ' + fmt)
 
+    @staticmethod
+    def guess_fmt(fp, default, ignore_fps=(sys.stdin, sys.stdout, sys.stderr)):
+        """
+        Guess format of a file object based on its extention.
+
+        """
+        if fp in ignore_fps:
+            return default
+
+        fmt = os.path.splitext(fp.name)[-1].split('.')[-1].lower()
+
+        if fmt == 'yml':
+            fmt = 'yaml'
+
+        return fmt if fmt else default
+
     @staticmethod
     def get_loader(fmt, **kwargs):
         if fmt == 'json':
@@ -115,7 +152,27 @@ class App(object):
         raise RuntimeError('Unsupported input format: ' + fmt)
 
     def load(self, file_):
-        return self.loader.load(file_)
+        if self.args.ifmt == 'auto':
+            fmt = self.guess_fmt(file_, 'json')
+        else:
+            fmt = self.args.ifmt
+
+        fmt_opts = self._decode_fmt_opts(self.args.ifmt_opts)
+        return self.get_loader(fmt, **fmt_opts).load(file_)
+
+    @staticmethod
+    def override_excepthook():
+        """
+        Change default exit code for unhandled exceptions from 1 to 127.
+        Mainly for diff tool (version control systems treat 1 as difference
+        in files).
+
+        """
+        def overrided(*args, **kwargs):
+            sys.__excepthook__(*args, **kwargs)  # do all the same
+            raise SystemExit(127)  # but change exit code
+
+        sys.excepthook = overrided
 
     def run(self):
         raise NotImplementedError
@@ -211,20 +268,8 @@ class IniLoader(Loader):
     def __init__(self, **kwargs):
         super().__init__()
 
-        if sys.version[0] == '2':
-            from ConfigParser import ConfigParser
-
-            class Py2ConfigParserWrapper(ConfigParser):
-                # old ConfigParser has no method read_string
-                def read_string(self, data):
-                    from StringIO import StringIO
-                    sio = StringIO(data)
-                    return ConfigParser.readfp(self, sio)
-
-            self.decoder = Py2ConfigParserWrapper(**kwargs)
-        else:
-            from configparser import ConfigParser
-            self.decoder = ConfigParser(**kwargs)
+        from configparser import ConfigParser
+        self.decoder = ConfigParser(**kwargs)
 
     def decode(self, data):
         self.decoder.read_string(data)
