@@ -30,6 +30,12 @@ class App(nested_diff.cli.App):
     Diff tool for nested data structures
 
     """
+    default_ifmt = 'auto'
+    default_ofmt = 'auto'
+
+    supported_ifmts = ('auto', 'ini', 'json', 'yaml')
+    supported_ofmts = ('auto', 'json', 'term', 'text', 'yaml')
+
     def diff(self, a, b):
         """
         Return diff for passed objects
@@ -43,7 +49,7 @@ class App(nested_diff.cli.App):
             multiline_diff_context=self.args.text_ctx,
             A=self.args.A,
             N=self.args.N,
-            O=self.args.O,
+            O=self.args.O,  # noqa: E741
             R=self.args.R,
             U=self.args.U,
         )
@@ -56,44 +62,25 @@ class App(nested_diff.cli.App):
             parents=(parent,)
         )
 
-        parser.add_argument('file1', type=argparse.FileType())
-        parser.add_argument('file2', type=argparse.FileType())
-
         parser.add_argument(
             '--text-ctx',
             default=3,
             metavar='NUM',
             type=int,
-            help='amount of context lines for multiline strings diffs; ' +
+            help='amount of context lines for multiline strings diffs; '
                  'negative value will disable multiline diffs, default is 3'
         )
 
-        parser.add_argument(
-            '--ifmt',
-            type=str,
-            default='json',
-            choices=('ini', 'json', 'yaml'),
-            help='input files format; "json" used by default',
-        )
-
-        parser.add_argument(
-            '--ofmt',
-            type=str,
-            default='auto',
-            choices=('auto', 'json', 'term', 'text', 'yaml'),
-            help='output format',
-        )
-
         parser.add_argument(
             '--out',
             default=sys.stdout,
             metavar='FILE',
             type=argparse.FileType('w'),
-            help='output file; STDERR is used if omitted',
+            help='output file; STDOUT is used if omitted',
         )
 
         parser.add_argument('-A', type=int, choices=(0, 1), default=1,
-                            help='show added items; enabled by deefault')
+                            help='show added items; enabled by default')
         parser.add_argument('-N', type=int, choices=(0, 1), default=1,
                             help='show item\'s new values; enabled by default')
         parser.add_argument('-O', type=int, choices=(0, 1), default=1,
@@ -105,6 +92,11 @@ class App(nested_diff.cli.App):
 
         return parser
 
+    @staticmethod
+    def get_argparser_positional_args():
+        yield 'file1', {'type': argparse.FileType()}
+        yield 'file2', {'type': argparse.FileType()}
+
     def get_dumper(self, fmt, **kwargs):
         if fmt == 'auto':
             if self.args.out.isatty():
@@ -130,15 +122,14 @@ class App(nested_diff.cli.App):
             self.load(self.args.file1),
             self.load(self.args.file2),
         )
+        exit_code = 0 if not diff or 'U' in diff else 1
 
         self.dump(self.args.out, diff)
 
+        return exit_code
+
 
 class AbstractFmtDumper(nested_diff.cli.Dumper):
-    def __init__(self, **kwargs):
-        super().__init__()
-        import nested_diff.fmt
-
     def encode(self, data):
         return self.encoder.format(data)
 
@@ -151,18 +142,16 @@ class AbstractFmtDumper(nested_diff.cli.Dumper):
 class TermDumper(AbstractFmtDumper):
     def __init__(self, **kwargs):
         super().__init__()
+        import nested_diff.fmt
         self.encoder = nested_diff.fmt.TermFormatter(**self.get_opts(kwargs))
 
 
 class TextDumper(AbstractFmtDumper):
     def __init__(self, **kwargs):
         super().__init__()
+        import nested_diff.fmt
         self.encoder = nested_diff.fmt.TextFormatter(**self.get_opts(kwargs))
 
 
 def cli():
-    App().run()
-
-
-if __name__ == '__main__':
-    App().run()
+    return App().run()
