@@ -18,7 +18,6 @@
 Patch tool for nested diff.
 
 """
-
 import argparse
 import nested_diff.cli
 
@@ -36,11 +35,13 @@ class App(nested_diff.cli.App):
             parents=(parent,)
         )
 
-        parser.add_argument('target_file')
-        parser.add_argument('patch_file', type=argparse.FileType())
-
         return parser
 
+    @staticmethod
+    def get_argparser_positional_args():
+        yield 'target_file', {}
+        yield 'patch_file', {'type': argparse.FileType()}
+
     @staticmethod
     def patch(target, diff):
         """
@@ -60,10 +61,8 @@ class App(nested_diff.cli.App):
 
         self.dump(argparse.FileType('w')(self.args.target_file), patched)
 
+        return 0
+
 
 def cli():
-    App().run()
-
-
-if __name__ == '__main__':
-    App().run()
+    return App().run()
